@@ -26,4 +26,8 @@ pub use self::bezier::BezierSurf;
 pub use self::bezier::RatBezierCurve;
 pub use self::bezier::BezierCircle;
 pub use self::bezier::BezierCurveDemo1;
+pub use self::teapot::TEAPOT_PACTHES;
+pub use self::teapot::TEAPOT_VERTICES;
+pub use self::teapot::BezierTeapot;
 mod bezier;
+mod teapot;
